@@ -10,8 +10,7 @@
 setMethod("semPlotModel.S4",signature("lavaan"),function(object){
 
   if (class(object)!="lavaan") stop("Input must me a 'lavaan' object")
-  
-  
+
   # Extract parameter estimates:
   pars <- parameterEstimates(object,standardized=TRUE)
   list <- inspect(object,"list")
@@ -61,19 +60,15 @@ setMethod("semPlotModel.S4",signature("lavaan"),function(object){
   semModel@Pars$edge[pars$op=="~1"] <- "int"
   semModel@Pars$edge[grepl("\\|",pars$op)] <- "|"
   
-  # Remove constraints:
-  semModel@Pars  <- semModel@Pars[!pars$op %in% c('<', '>'),]
-  
   # Move thresholds to Thresholds slot:
   semModel@Thresholds <- semModel@Pars[grepl("\\|",semModel@Pars$edge),-(3:4)]
+  
+  # Remove constraints and weird stuff:
+  semModel@Pars  <- semModel@Pars[!pars$op %in% c('<', '>',':=','<','>','==','|'),]
+  
   # Remove thresholds from Pars:
 #   semModel@Pars <- semModel@Pars[!grepl("\\|",semModel@Pars$edge),]
   
-
-  # Remove weird edges:
-  semModel@Pars <- semModel@Pars[!pars$op%in%c(':=','<','>','==','|'),]
-
-  
   semModel@Vars <- data.frame(
     name = c(varNames,factNames),
     manifest = c(varNames,factNames)%in%varNames,
